package Kephra::Plugin;
our $VERSION = '0.00';

=head1 NAME

Kephra::Plugin - dummy base class for all Extentions/Plugins 

=head1 DESCRIPTION

=cut

use strict;
use warnings;

sub install{}
sub deinstall{}
sub init {}
1;